@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -624,14 +624,47 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
             gtk_entry_set_text (GTK_ENTRY (conndlg->priv->uri_entry), con->uri);
 
             gtk_entry_set_text (GTK_ENTRY (conndlg->priv->server_entry), gnome_vfs_uri_get_host_name (uri));
-            // gtk_entry_set_text (GTK_ENTRY (conndlg->priv->share_entry), ???);
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), gnome_vfs_uri_get_path (uri));
-            // gtk_entry_set_text (GTK_ENTRY (conndlg->priv->domain_entry), ???);
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), gnome_vfs_uri_get_user_name (uri));
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->password_entry), gnome_vfs_uri_get_password (uri));
 
+            const gchar *path = gnome_vfs_uri_get_path (uri);
+            const gchar *user_name = gnome_vfs_uri_get_user_name (uri);
+            const gchar *password = gnome_vfs_uri_get_password (uri);
             guint port = gnome_vfs_uri_get_host_port (uri);
 
+            if (con->method==CON_SMB)
+            {
+                gchar **a = g_strsplit (path, "/", 3);
+
+                if (g_strv_length (a) > 2)
+                {
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->share_entry), a[1]);
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), a[2]);
+                }
+                else
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
+
+                g_strfreev(a);
+
+                a = g_strsplit (user_name, ";", 2);
+
+                if (g_strv_length (a) > 1)
+                {
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->domain_entry), a[0]);
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), a[1]);
+                }
+                else
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+
+                g_strfreev(a);
+            }
+            else
+            {
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+            }
+
+            if (password)
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->password_entry), password);
+
             if (port)
                 gtk_entry_set_text (GTK_ENTRY (conndlg->priv->port_entry), stringify(port).c_str());
 
